@@ -106,7 +106,7 @@ tram <- function(formula, data, subset, weights, offset, cluster, na.action = na
                  transformation = c("discrete", "linear", "logarithmic", "smooth"),
                  LRtest = TRUE, 
                  prob = c(.1, .9), support = NULL, bounds = NULL, add = c(0, 0), order = 6, negative =
-                 TRUE, scale = TRUE, model_only = FALSE, ...) 
+                 TRUE, scale = TRUE, extrapolate = FALSE, model_only = FALSE, ...) 
 {
 
     if (!inherits(td <- formula, "tram_data")) {
@@ -119,7 +119,8 @@ tram <- function(formula, data, subset, weights, offset, cluster, na.action = na
 
     rvar <- asvar(td$response, td$rname, prob = prob, support = support,
                   bounds = bounds, add = add)
-    rbasis <- mkbasis(rvar, transformation = transformation, order = order)
+    rbasis <- mkbasis(rvar, transformation = transformation, order = order,
+                      extrapolate = extrapolate)
 
     iS <- NULL
     if (!is.null(td$mt$s)) 
